#!/usr/bin/perl -w
#
#   FDN::Config test de tables de correspondance
#
#   $Id: 11config.pl,v 1.2 2005-07-19 15:02:31 benjamin Exp $
#   $Name: FDN_LIBS_V_1_2_32 $
#

use Test::More;
use FDN::Common::Config;

use strict;
my $nbtest = 0;

$FDN::Common::Config::CONFIG_ROOT = './t/';

# 1
my $tbl = Rewrite_Table('dummy.tbl', 'utile', {});
is($tbl, undef, 	 	'Non-existent config file');
BEGIN { $nbtest += 1; }

[-f 't/test.tbl.bin' ] && system('rm -f t/test.tbl.bin');

# 1
$tbl = Rewrite_Table('test.tbl', 'utile', {
	CHAMP1 => "test1",
	CHAMP2 => "test2",
	CHAMP3 => "",
	CHAMP6 => "foo",
	CHAMP7 => "fooabar",
	CHAMP8 => "fooabar",
	CHAMP9 => "20030824123524",
	CHAMP11 => "fooacbardac",
	CHAMP12 => "bar",
	CHAMP13 => '',
	CHAMP14 => undef,
	CHAMP15 => 'un',
	CHAMP16 => 'deux',
	CHAMP17 => 't1',
	CHAMP18 => 't2',
	CHAMP19 => 12
});
ok(defined $tbl, 		'Loaded test.tbl config file');

# 2
is(ref $tbl, 'HASH', 		'$tbl is a HASH reference');

# 3
is($tbl->{'titre'}, "Section utile",
				q($tbl->{'titre'} correctly set));

# 4
is(ref $tbl->{'valeurs'}, "ARRAY",
				q($tbl->{'valeurs'} is a ARRAY ref));

# 5,6
is($tbl->{'valeurs'}[0]{'nom'}, "aucune action", "aucune action...");
is($tbl->{'valeurs'}[0]{'valeur'}, "test1", "          ... ok");

# 7,8
is($tbl->{'valeurs'}[1]{'nom'}, "enum simple", "enum simple...");
is($tbl->{'valeurs'}[1]{'valeur'}, "valeur 2", "          ... ok");

# 9,10
is($tbl->{'valeurs'}[2]{'nom'}, "enum vide", "enum vide...");
is($tbl->{'valeurs'}[2]{'valeur'}, "valeur vide1", "          ... ok");

# 11,12
is($tbl->{'valeurs'}[3]{'nom'}, "enum suppr", "enum suppr...");
is($tbl->{'valeurs'}[3]{'valeur'}, "valeur inconnue (null)", "          ... ok");

# 13,14
is($tbl->{'valeurs'}[4]{'nom'}, "enum default", "enum default...");
is($tbl->{'valeurs'}[4]{'valeur'}, "valeur inconnue", "          ... ok");

# 15,16
is($tbl->{'valeurs'}[5]{'nom'}, "texte", "texte...");
is($tbl->{'valeurs'}[5]{'valeur'}, 'petit texte', "          ... ok");

# 17,18
is($tbl->{'valeurs'}[6]{'nom'}, "asterisque", "asterisque...");
is($tbl->{'valeurs'}[6]{'valeur'}, 'petit texte 2', "          ... ok");

# 19,20
is($tbl->{'valeurs'}[7]{'nom'}, "regexp", "regexp...");
is($tbl->{'valeurs'}[7]{'valeur'}, 'foobbar', "          ... ok");

# 21,22
is($tbl->{'valeurs'}[8]{'nom'}, "regexp globale", "regexp globale...");
is($tbl->{'valeurs'}[8]{'valeur'}, 'foobbbr', "          ... ok");

# 23,24
is($tbl->{'valeurs'}[9]{'nom'}, "regexp arrire", "regexp avec rfrence arrire...");
is($tbl->{'valeurs'}[9]{'valeur'}, '24/08/2003 12:35:24', "          ... ok");

# 25,26
is($tbl->{'valeurs'}[10]{'nom'}, "code", "code...");
is($tbl->{'valeurs'}[10]{'valeur'}, 'fooabar', "          ... ok");

# 27,28
is($tbl->{'valeurs'}[11]{'nom'}, "regexps en cascade", "regexps en cascade...");
is($tbl->{'valeurs'}[11]{'valeur'}, 'foobdbbrdbd', "          ... ok");

# 29,30
is($tbl->{'valeurs'}[12]{'nom'}, "regexp, enum", "regexp puis enum...");
is($tbl->{'valeurs'}[12]{'valeur'}, 'ok', "          ... ok");

# 31,32
is($tbl->{'valeurs'}[13]{'nom'}, "regexp vide", "regexp sur une valeur vide...");
is($tbl->{'valeurs'}[13]{'valeur'}, '', "          ... ok");

# 33,34
is($tbl->{'valeurs'}[14]{'nom'}, "regexp undef", "regexp sur une valeur undef");
is($tbl->{'valeurs'}[14]{'valeur'}, undef, "          ... ok");

# 35,36
is($tbl->{'valeurs'}[15]{'nom'}, 'divclass', 'divclass');
is($tbl->{'valeurs'}[15]{'valeur'}, '<div class="toto">un</div>', 'divclass');

# 37,38
is($tbl->{'valeurs'}[16]{'nom'}, 'spanclass', 'spanclass');
is($tbl->{'valeurs'}[16]{'valeur'}, '<span class="titi">deux</span>', 'spanclass');

# 39,30
is($tbl->{'valeurs'}[17]{'nom'}, 'regwrap1', 'regwrap');
is($tbl->{'valeurs'}[17]{'valeur'}, 'debut/t1/fin', 'regwrap');

# 41,42
is($tbl->{'valeurs'}[18]{'nom'}, 'regwrap2', 'regwrap');
is($tbl->{'valeurs'}[18]{'valeur'}, 'debutt2milieut2fin', 'regwrap');

# 43,44
is($tbl->{'valeurs'}[19]{'nom'}, 'linkto', 'linkto');
is($tbl->{'valeurs'}[19]{'valeur'}, '<a href="../test.cgi?a=b&info=12&x=12&y=z">12</a>', 'linkto');
BEGIN { $nbtest += 44; }

# 1
$tbl = undef;
$tbl = Rewrite_Table('test.tbl', 'utile', {
	CHAMP1 => "test1",
	CHAMP2 => "test2",
	CHAMP3 => "",
	CHAMP6 => "foo",
	CHAMP7 => "fooabar",
	CHAMP8 => "fooabar",
	CHAMP9 => "20030824123524",
	CHAMP11 => "fooacbardac",
	CHAMP12 => "bar",
	CHAMP13 => '',
	CHAMP14 => undef,
});
ok(defined $tbl, 		'Reloaded test.tbl config file');

# 2,3
is($tbl->{'valeurs'}[1]{'nom'}, "enum simple", "enum simple...");
is($tbl->{'valeurs'}[1]{'valeur'}, "valeur 2", "          ... ok");

# 4,5
is($tbl->{'valeurs'}[2]{'nom'}, "enum vide", "enum vide...");
is($tbl->{'valeurs'}[2]{'valeur'}, "valeur vide1", "          ... ok");

# 6,7
is($tbl->{'valeurs'}[3]{'nom'}, "enum suppr", "enum suppr...");
is($tbl->{'valeurs'}[3]{'valeur'}, "valeur inconnue (null)", "          ... ok");

# 8,9
is($tbl->{'valeurs'}[4]{'nom'}, "enum default", "enum default...");
is($tbl->{'valeurs'}[4]{'valeur'}, "valeur inconnue", "          ... ok");
BEGIN { $nbtest += 9; }

my $props = {
	'PR1' => '1111',
	'PR2' => [ 'essai', 'eval' ],
	'in'  => { 'PRI2' => '2222' },
	'in2' => [ { 'PRI2' => 'rien' },
	           { 'PRI2' => 'non plus' } ]
};

$tbl = undef;
$tbl = Rewrite_Props('test.tbl','props','t/pr.tpl',$props);

my $res;
$res =	"Des proprietes\n".
	"\n".
	"  Prop 1 = 2111\n\n".
	"  Prop 2 = assai\n\n".
	"  Prop 2 = aval\n\n".
	"  Propint = Internes\n\n".
	"  Prop int 2 = 3222\n\n".
	"\n\n".
	"  in2 = Internes 2\n\n".
	"  Prop int 1 = Constant\n\n".
	"\n\n".
	"  in2 = Internes 2\n\n".
	"  Prop int 1 = Constant\n\n".
	"\n\n"
	;

# 1
is ( $tbl, $res, "Re-ecriture des proprietes");
BEGIN { $nbtest += 1; }


BEGIN { plan tests => $nbtest; }

#
# Just to make vim's color syntax engine know that this '.t' file is a Perl
# script :
#
# vim:se filetype=perl:
#
